==> eisp-mdm-2.1.9-RELEASE-classes.jar: com/biz/eisp/mdm/terminal/sql/TmTermCustPostDao_findTermCustPostList.sql <==
SELECT distinct tc.id,
	tc.business_group businessGroup,
	tp.id positionId,
	tp.position_name positionName,
	term.id terminalId,
	term.terminal_code terminalCode,
	term.terminal_name terminalName,
	u.fullname fullName,
	u.mobilephone mobilephone,
	term.terminal_type terminalType,
	cust.id custId,
	cust.customer_name customerName,
	tr.org_name businessGroupOrgName,
	tr.id businessGroupOrgId,
	(SELECT LISTAGG(detail_code,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'channelCode' AND d.business_group = tc.business_group) AS channelCode,
    (SELECT LISTAGG(detail_name,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'channelCode' AND d.business_group = tc.business_group) AS channelName,
    (SELECT LISTAGG(detail_code,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'productCode' AND d.business_group = tc.business_group) AS productCode,
    (SELECT LISTAGG(detail_name,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'productCode' AND d.business_group = tc.business_group) AS productName,
    (SELECT LISTAGG(detail_code,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'businessAreaCode' AND d.business_group = tc.business_group) AS businessAreaCode,
    (SELECT LISTAGG(detail_name,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'businessAreaCode' AND d.business_group = tc.business_group) AS businessAreaName
FROM TM_R_TERM_CUST_POS_BG tc
LEFT JOIN TM_POSITION tp ON tp.ID=tc.position_id 
left join tm_r_user_position up on up.position_id=tc.position_id and up.is_main=0
left join tm_user u on u.id=up.user_id
LEFT JOIN TM_TERMINAL  term ON term.ID=tc.TERMINAL_ID
LEFT JOIN TM_CUSTOMER cust ON cust.ID=tc.CUSTOMER_ID
LEFT JOIN TM_ORG tr ON tr.ID=tc.ORG_ID
WHERE 1=1
<#if tmTermCustPostVo.positionId ?exists&&tmTermCustPostVo.positionId ?length gt 0>
	AND tc.POSITION_ID = '${tmTermCustPostVo.positionId}'
</#if> 
<#if tmTermCustPostVo.terminalCode ?exists&&tmTermCustPostVo.terminalCode ?length gt 0>
	AND term.TERMINAL_CODE LIKE '%${tmTermCustPostVo.terminalCode}%'
</#if> 
<#if tmTermCustPostVo.terminalName ?exists&&tmTermCustPostVo.terminalName ?length gt 0>
	AND term.TERMINAL_NAME LIKE '%${tmTermCustPostVo.terminalName}%'
</#if> 
<#if tmTermCustPostVo.terminalType ?exists&&tmTermCustPostVo.terminalType ?length gt 0>
	AND term.TERMINAL_TYPE = '${tmTermCustPostVo.terminalType}'
</#if> 
<#if tmTermCustPostVo.customerId ?exists&&tmTermCustPostVo.customerId ?length gt 0>
	AND tc.CUSTOMER_ID = '${tmTermCustPostVo.customerId}'
</#if> 
<#if tmTermCustPostVo.terminalId ?exists&&tmTermCustPostVo.terminalId ?length gt 0>
	AND tc.TERMINAL_ID = '${tmTermCustPostVo.terminalId}'
</#if>

==> eisp-mdm-2.3.3-RELEASE-classes.jar: com/biz/eisp/mdm/terminal/sql/TmTermCustPostDao_findTermCustPostList.sql <==
SELECT distinct tc.id,
	tc.business_group businessGroup,
	tp.id positionId,
	tp.position_name positionName,
	term.id terminalId,
	term.terminal_code terminalCode,
	term.terminal_name terminalName,
	u.fullname fullName,
	u.mobilephone mobilephone,
	term.terminal_type terminalType,
	cust.id custId,
	cust.customer_name customerName,
	tr.org_name businessGroupOrgName,
	tr.id businessGroupOrgId,
	(SELECT LISTAGG(detail_code,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'channelCode' AND d.business_group = tc.business_group) AS channelCode,
    (SELECT LISTAGG(detail_name,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'channelCode' AND d.business_group = tc.business_group) AS channelName,
    (SELECT LISTAGG(detail_code,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'productCode' AND d.business_group = tc.business_group) AS productCode,
    (SELECT LISTAGG(detail_name,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'productCode' AND d.business_group = tc.business_group) AS productName,
    (SELECT LISTAGG(detail_code,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'businessAreaCode' AND d.business_group = tc.business_group) AS businessAreaCode,
    (SELECT LISTAGG(detail_name,';') WITHIN GROUP (ORDER BY type_code)
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'businessAreaCode' AND d.business_group = tc.business_group) AS businessAreaName
FROM TM_R_TERM_CUST_POS_BG tc
LEFT JOIN TM_POSITION tp ON tp.ID=tc.position_id 
left join tm_r_user_position up on up.position_id=tc.position_id
left join tm_user u on u.id=up.user_id
LEFT JOIN TM_TERMINAL  term ON term.ID=tc.TERMINAL_ID
LEFT JOIN TM_CUSTOMER cust ON cust.ID=tc.CUSTOMER_ID
LEFT JOIN TM_ORG tr ON tr.ID=tc.ORG_ID
WHERE 1=1
<#if tmTermCustPostVo.positionId ?exists&&tmTermCustPostVo.positionId ?length gt 0>
	AND tc.POSITION_ID = '${tmTermCustPostVo.positionId}'
</#if> 
<#if tmTermCustPostVo.terminalCode ?exists&&tmTermCustPostVo.terminalCode ?length gt 0>
	AND term.TERMINAL_CODE LIKE '%${tmTermCustPostVo.terminalCode}%'
</#if> 
<#if tmTermCustPostVo.terminalName ?exists&&tmTermCustPostVo.terminalName ?length gt 0>
	AND term.TERMINAL_NAME LIKE '%${tmTermCustPostVo.terminalName}%'
</#if> 
<#if tmTermCustPostVo.terminalType ?exists&&tmTermCustPostVo.terminalType ?length gt 0>
	AND term.TERMINAL_TYPE = '${tmTermCustPostVo.terminalType}'
</#if> 
<#if tmTermCustPostVo.customerId ?exists&&tmTermCustPostVo.customerId ?length gt 0>
	AND tc.CUSTOMER_ID = '${tmTermCustPostVo.customerId}'
</#if> 
<#if tmTermCustPostVo.terminalId ?exists&&tmTermCustPostVo.terminalId ?length gt 0>
	AND tc.TERMINAL_ID = '${tmTermCustPostVo.terminalId}'
</#if>
